==> rym-util-v1.0.17.tar.gz: rym-util-v1.0.17/es/EsLogger.go <==
package es

import (
	"context"
	"encoding/json"
	"fmt"
	"git.168cad.top/zhengqiuyun/rym-util/exception"
	"git.168cad.top/zhengqiuyun/rym-util/log"
	"git.168cad.top/zhengqiuyun/rym-util/util"
	"github.com/olivere/elastic/v7"
	"sort"
	"time"
)

func getCurrentIndex() string {
	return indexNamePrefix + util.FormatDates(time.Now())
}

type ServerLogModel struct {
	ServerName   string `json:"serverName"`
	Env          string `json:"env"`
	TimeStamp    int64  `json:"timeStamp"`
	ThreadNo     string `json:"threadNo"`
	ServerIp     string `json:"serverIp"`
	ClientIp     string `json:"clientIp"`
	Token        string `json:"token"`
	CustomerId   uint32 `json:"customerId"`
	ClientSource string `json:"clientSource"`
	Url          string `json:"url"`
	Method       string `json:"method"`
	Request      string `json:"request"`
	Response     string `json:"response"`
	DealTimes    int64  `json:"dealTimes"`
}

func InsertEsLog(logInfo interface{}) {
	indexName := getCurrentIndex()
	put, err := Client.Index().
		Index(indexName).
		BodyJson(logInfo).
		Do(context.Background())
	if err != nil {
		log.Error(fmt.Sprintf("insert es log fail：%s", err.Error()))
	} else {
		log.Debug(fmt.Sprintf("insert es log success：%s", put.Id))
	}
}

func GroupField(indexName, field string, size, minCount int, excludeValues []string) []byte {
	if size == 0 {
		size = 30
	}
	aggregationQuery := elastic.NewTermsAggregation().Field(field).MinDocCount(minCount).Size(size)
	for _, excludeValue := range excludeValues {
		aggregationQuery.ExcludeValues(excludeValue)
	}
	if log.IsDebug() {
		source, _ := aggregationQuery.Source()
		queryByte, _ := json.Marshal(source)
		log.Info(fmt.Sprintf("查询条件：%s", string(queryByte)))
	}
	res, err := Client.Search(indexName).
		Aggregation("group_field", aggregationQuery).
		From(0).
		Size(0).
		Do(context.Background())
	if err != nil {
		exception.ThrowsErr(err)
	}
	bs, err := json.Marshal(res.Aggregations)
	if err != nil {
		exception.ThrowsErr(err)
	}
	return bs
}

func QueryLogs(indexName, filed, value string, from, size int) interface{} {
	if from <= 0 {
		from = 0
	}
	if size <= 0 {
		size = 10
	}
	query := elastic.NewBoolQuery().Must(elastic.NewTermQuery(filed, value))
	res, err := Client.Search(indexName).Query(query).
		From(from).
		Size(size).
		Do(context.Background())
	if err != nil {
		exception.ThrowsErr(err)
	}
	return res
}

type IndexInfo struct {
	Name  string `json:"name"`
	Count int    `json:"count"`
	Size  string `json:"size"`
}

func AllIndex() interface{} {
	res, err := Client.CatIndices().Do(context.Background())
	if err != nil {
		exception.ThrowsErr(err)
	}
	var keys []string
	var sizeMap = make(map[string]IndexInfo)
	for _, row := range res {
		keys = append(keys, row.Index)
		sizeMap[row.Index] = IndexInfo{row.Index, row.DocsCount, row.StoreSize}
	}
	sort.Strings(keys)
	data := make([]IndexInfo, len(keys))
	for i, key := range keys {
		data[i] = sizeMap[key]
	}
	return data
}

func DeleteIndex(indexName string) interface{} {
	res, err := Client.DeleteIndex(indexName).
		Do(context.Background())
	if err != nil {
		exception.ThrowsErr(err)
	}
	return res
}

==> rym-util-v1.0.52.tar.gz: rym-util-v1.0.52/es/EsLogger.go <==
package es

import (
	"context"
	"encoding/json"
	"fmt"
	"git.168cad.top/zhengqiuyun/rym-util/conf"
	"git.168cad.top/zhengqiuyun/rym-util/exception"
	"git.168cad.top/zhengqiuyun/rym-util/log"
	"git.168cad.top/zhengqiuyun/rym-util/util"
	"github.com/olivere/elastic/v7"
	"sort"
	"time"
)

func getCurrentIndex() string {
	if conf.LogIndexNamePrefix == "" {
		return indexNamePrefix + util.FormatDates(time.Now())
	} else {
		return conf.LogIndexNamePrefix + util.FormatDates(time.Now())
	}
}

type ServerLogModel struct {
	ServerName   string `json:"serverName"`
	Env          string `json:"env"`
	TimeStamp    int64  `json:"timeStamp"`
	ThreadNo     string `json:"threadNo"`
	ServerIp     string `json:"serverIp"`
	ClientIp     string `json:"clientIp"`
	Token        string `json:"token"`
	CustomerId   uint32 `json:"customerId"`
	ClientSource string `json:"clientSource"`
	Url          string `json:"url"`
	Method       string `json:"method"`
	Request      string `json:"request"`
	Response     string `json:"response"`
	DealTimes    int64  `json:"dealTimes"`
}

func InsertEsLog(logInfo interface{}) {
	indexName := getCurrentIndex()
	put, err := getRedisClient().Index().
		Index(indexName).
		BodyJson(logInfo).
		Do(context.Background())
	if err != nil {
		log.Error(fmt.Sprintf("insert es log fail：%s", err.Error()))
	} else {
		log.Debug(fmt.Sprintf("insert es log success：%s", put.Id))
	}
}

func GroupField(indexName, field string, size, minCount int, excludeValues []string) []byte {
	if size == 0 {
		size = 30
	}
	aggregationQuery := elastic.NewTermsAggregation().Field(field).MinDocCount(minCount).Size(size)
	for _, excludeValue := range excludeValues {
		aggregationQuery.ExcludeValues(excludeValue)
	}
	if log.IsDebug() {
		source, _ := aggregationQuery.Source()
		queryByte, _ := json.Marshal(source)
		log.Info(fmt.Sprintf("查询条件：%s", string(queryByte)))
	}
	res, err := getRedisClient().Search(indexName).
		Aggregation("group_field", aggregationQuery).
		From(0).
		Size(0).
		Do(context.Background())
	if err != nil {
		exception.ThrowsErr(err)
	}
	bs, err := json.Marshal(res.Aggregations)
	if err != nil {
		exception.ThrowsErr(err)
	}
	return bs
}

func QueryLogs(indexName, filed, value string, from, size int) interface{} {
	if from <= 0 {
		from = 0
	}
	if size <= 0 {
		size = 10
	}
	query := elastic.NewBoolQuery().Must(elastic.NewTermQuery(filed, value))
	res, err := getRedisClient().Search(indexName).Query(query).
		From(from).
		Size(size).
		Do(context.Background())
	if err != nil {
		exception.ThrowsErr(err)
	}
	return res
}

type IndexInfo struct {
	Name  string `json:"name"`
	Count int    `json:"count"`
	Size  string `json:"size"`
}

func AllIndex() interface{} {
	res, err := getRedisClient().CatIndices().Do(context.Background())
	if err != nil {
		exception.ThrowsErr(err)
	}
	var keys []string
	var sizeMap = make(map[string]IndexInfo)
	for _, row := range res {
		keys = append(keys, row.Index)
		sizeMap[row.Index] = IndexInfo{row.Index, row.DocsCount, row.StoreSize}
	}
	sort.Strings(keys)
	data := make([]IndexInfo, len(keys))
	for i, key := range keys {
		data[i] = sizeMap[key]
	}
	return data
}

func DeleteIndex(indexName string) interface{} {
	res, err := getRedisClient().DeleteIndex(indexName).
		Do(context.Background())
	if err != nil {
		exception.ThrowsErr(err)
	}
	return res
}
